;; Generated package description from gnorb.el
(define-package "gnorb" "1.6.0" "Glue code between Gnus, Org, and BBDB" '((cl-lib "0.5")) :url "http://elpa.gnu.org/packages/gnorb.html" :keywords '("mail" "org" "gnus" "bbdb" "todo" "task"))
